@@ -22,12 +22,13 @@
 
 #include <QPalette>
 #include <QTimer>
+#include <QDebug>
+#include <QStandardPaths>
 
-#include <KStandardDirs>
-#include <KLocale>
 #include <KgDifficulty>
 #include <KgThemeProvider>
 #include <KColorScheme>
+#include <KLocalizedString>
 
 static const int MIN_MARGIN = 50;
 static const int GAME_TIME_DELAY = 1000;
@@ -43,19 +44,19 @@ KBounceGameWidget::KBounceGameWidget( QWidget* parent )
 , m_lives( 0 )
 , m_time( 0 )
 , m_vertical( false )
-, m_soundTimeout( KStandardDirs::locate( "appdata", "sounds/timeout.wav" ) )
+, m_soundTimeout( QStandardPaths::locate( QStandardPaths::DataLocation, "sounds/timeout.wav" ) )
 {
     m_board = new KBounceBoard( &m_renderer );
-    connect( m_board, SIGNAL(fillChanged(int)), this, SLOT(onFillChanged(int)) );
-    connect( m_board, SIGNAL(wallDied()), this, SLOT(onWallDied()) );
+    connect(m_board, &KBounceBoard::fillChanged, this, &KBounceGameWidget::onFillChanged);
+    connect(m_board, &KBounceBoard::wallDied, this, &KBounceGameWidget::onWallDied);
 
     m_overlay = new QGraphicsPixmapItem();
     m_overlay->hide();
 
     m_clock = new QTimer( this );
     m_clock->setInterval( GAME_TIME_DELAY );
-    connect( m_clock, SIGNAL(timeout()), this, SLOT(tick()) );
-	connect( this, SIGNAL(livesChanged(int)),this,SLOT(onLivesChanged(int)) );
+    connect(m_clock, &QTimer::timeout, this, &KBounceGameWidget::tick);
+	connect(this, &KBounceGameWidget::livesChanged, this, &KBounceGameWidget::onLivesChanged);
 
     setMouseTracking( true );
 
@@ -80,7 +81,7 @@ int KBounceGameWidget::level()
 
 int KBounceGameWidget::score()
 {
-    kDebug() << "Score:" << m_score;
+    qDebug() << "Score:" << m_score;
     return m_score;
 }
 
@@ -159,7 +160,7 @@ void KBounceGameWidget::setSuspended( bool val )
 
 void KBounceGameWidget::settingsChanged()
 {
-    kDebug() << "Settings changed";
+    qDebug() << "Settings changed";
 
     if (KBounceSettings::useRandomBackgroundPictures())
     {
@@ -256,7 +257,7 @@ void KBounceGameWidget::tick()
 
 void KBounceGameWidget::resizeEvent( QResizeEvent* ev )
 {
-    kDebug() << "Size" << ev->size();
+    qDebug() << "Size" << ev->size();
 
     m_renderer.setBackgroundSize( ev->size() );
 
@@ -466,5 +467,5 @@ void KBounceGameWidget::updateCursor()
         unsetCursor();
 }
 
-#include "gamewidget.moc"
+
 
